import { FeedbackCommon, FeedbackPosition, FeedbackType } from './common';
export { FeedbackType };
export { FeedbackPosition };
export class Feedback extends FeedbackCommon {
    show(options) {
        return new Promise((resolve) => {
            const icon = options.icon ? UIImage.imageNamed(options.icon) : null;
            const hideOnSwipe = true;
            const hideOnTap = true;
            const message = ISMessages.cardAlertWithTitleMessageIconImageDurationHideOnSwipeHideOnTapAlertTypeAlertPosition(options.title, options.message, icon, options.duration ? options.duration / 1000 : 4.0, hideOnSwipe, hideOnTap, Feedback.getType(options.type), Feedback.getPosition(options.position));
            if (options.backgroundColor) {
                message.alertViewBackgroundColor = options.backgroundColor.ios;
            }
            if (options.titleColor) {
                message.titleLabelTextColor = options.titleColor.ios;
            }
            const titleSize = options.titleSize || 16;
            const messageSize = options.messageSize || 13;
            if (options.titleFont) {
                message.titleLabelFont = UIFont.fontWithNameSize(options.titleFont, titleSize);
            }
            else {
                message.titleLabelFont = UIFont.boldSystemFontOfSize(titleSize);
            }
            if (options.messageFont) {
                message.messageLabelFont = UIFont.fontWithNameSize(options.messageFont, messageSize);
            }
            else {
                message.messageLabelFont = UIFont.systemFontOfSize(messageSize);
            }
            if (options.messageColor) {
                message.messageLabelTextColor = options.messageColor.ios;
            }
            message.showDidBeginDidHide(() => {
                if (options.onTap) {
                    options.onTap();
                }
            }, (animating) => {
                if (options.onShow) {
                    options.onShow(animating);
                }
            }, () => {
                if (options.onHide) {
                    options.onHide();
                }
            });
            resolve();
        });
    }
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    hide(options) {
        return new Promise((resolve) => {
            ISMessages.hideAlertAnimated(true);
            resolve();
        });
    }
    static getType(type) {
        if (type === undefined || type === null || type === FeedbackType.Custom) {
            return 4 /* ISAlertType.Custom */;
        }
        else if (type === FeedbackType.Warning) {
            return 2 /* ISAlertType.Warning */;
        }
        else if (type === FeedbackType.Error) {
            return 1 /* ISAlertType.Error */;
        }
        else if (type === FeedbackType.Info) {
            return 3 /* ISAlertType.Info */;
        }
        else {
            return 0 /* ISAlertType.Success */;
        }
    }
    static getPosition(position) {
        if (!position || position === FeedbackPosition.Top) {
            return 0 /* ISAlertPosition.Top */;
        }
        else {
            return 1 /* ISAlertPosition.Bottom */;
        }
    }
}
//# sourceMappingURL=index.ios.js.map